@@ -16,12 +16,13 @@ FUEL = [autogas, diesel, erdgas, superplus, super, normal]
 
 class ITBObject:
     def __init__(self):
-        self.version = "1.0.15"
+        self.version = "1.0.16"
         self.author = "Ludy87"
         self.project = "Ich tanke billig"
         self.page = "https://www.astra-g.org/"
-    def toJSON(self):
-        return json.dumps(self, default=lambda o: o.__dict__, indent=4)
+
+def toJSON(self):
+    return json.dumps(self, default=lambda o: o.__dict__, indent=4)
 
 def connenctionLib(url):
     user_agent = {
@@ -101,7 +102,7 @@ def getStations(kraftstoff = diesel, place = '123', limit = '-1', asJson = False
                 i += 1
                 me.stations.append(json_data)
     if asJson:
-        return me.toJSON()
+        return toJSON(me)
     else:
         return me
 
